@@ -337,8 +337,9 @@ static adat_cmd_def_t adat_cmd_get_freq =
 
 static adat_cmd_list_t adat_cmd_list_get_freq =
 {
-    1,
+    2,
     {
+        &adat_cmd_display_off,
         &adat_cmd_get_freq
     }
 };
@@ -360,20 +361,20 @@ static adat_cmd_def_t adat_cmd_set_freq =
 
 static adat_cmd_list_t adat_cmd_list_set_freq =
 {
-    4,
+    3,
     {
         &adat_cmd_display_off,
         &adat_cmd_set_freq,
         &adat_cmd_get_freq,
-        &adat_cmd_display_on
     }
 };
 // -- GET VFO --
 
 static adat_cmd_list_t adat_cmd_list_get_vfo =
 {
-    1,
+    2,
     {
+        &adat_cmd_display_off,
         &adat_cmd_get_freq,
     }
 };
@@ -395,8 +396,9 @@ static adat_cmd_def_t adat_cmd_get_mode =
 
 static adat_cmd_list_t adat_cmd_list_get_mode =
 {
-    1,
+    2,
     {
+        &adat_cmd_display_off,
         &adat_cmd_get_mode
     }
 };
@@ -419,11 +421,10 @@ static adat_cmd_def_t adat_cmd_set_vfo =
 
 static adat_cmd_list_t adat_cmd_list_set_vfo =
 {
-    3,
+    2,
     {
         &adat_cmd_display_off,
-        &adat_cmd_set_vfo,
-        &adat_cmd_display_on
+        &adat_cmd_set_vfo
     }
 };
 
@@ -445,12 +446,11 @@ static adat_cmd_def_t adat_cmd_set_mode =
 
 static adat_cmd_list_t adat_cmd_list_set_mode =
 {
-    4,
+    3,
     {
         &adat_cmd_display_off,
         &adat_cmd_set_vfo,
         &adat_cmd_set_mode,
-        &adat_cmd_display_on
     }
 };
 
@@ -471,12 +471,10 @@ static adat_cmd_def_t adat_cmd_set_ptt =
 
 static adat_cmd_list_t adat_cmd_list_set_ptt =
 {
-    1,
+    2,
     {
-        // &adat_cmd_display_off,
-        // &adat_cmd_set_vfo,
         &adat_cmd_set_ptt,
-        // &adat_cmd_display_on
+        &adat_cmd_display_off
     }
 };
 
@@ -497,8 +495,9 @@ static adat_cmd_def_t adat_cmd_get_ptt =
 
 static adat_cmd_list_t adat_cmd_list_get_ptt =
 {
-    1,
+    2,
     {
+        &adat_cmd_display_off,
         &adat_cmd_get_ptt
     }
 };
@@ -535,17 +534,28 @@ static adat_cmd_list_t adat_cmd_list_open_adat =
 {
     8,
     {
+        &adat_cmd_display_off,
         &adat_cmd_get_serial_nr,
         &adat_cmd_get_id_code,
         &adat_cmd_get_fw_version,
         &adat_cmd_get_gui_fw_version,
         &adat_cmd_get_hw_version,
         &adat_cmd_get_options,
-        &adat_cmd_set_callsign,
+        &adat_cmd_set_callsign
+    }
+};
+
+// -- CLOSE ADAT --
+
+static adat_cmd_list_t adat_cmd_list_close_adat =
+{
+    1,
+    {
         &adat_cmd_display_on
     }
 };
 
+
 // -- ADAT SPECIAL: RECOVER FROM ERROR --
 
 static adat_cmd_list_t adat_cmd_list_recover_from_error =
@@ -568,8 +578,11 @@ static adat_cmd_list_t adat_cmd_list_recover_from_error =
 
 size_t trimwhitespace( char *out, size_t len, const char *str )
 {
+    char    *end      = NULL;
+    size_t   out_size = 0;
 
     gFnLevel++;
+
     rig_debug( RIG_DEBUG_TRACE,
               "*** ADAT: %d %s (%s:%d): ENTRY. In -> \"%s\", %d.\n",
               gFnLevel, __func__, __FILE__, __LINE__, str, len );
@@ -580,9 +593,6 @@ size_t trimwhitespace( char *out, size_t len, const char *str )
         return 0;
     }
 
-    const char *end;
-    size_t out_size;
-
     // Trim leading space
     while(isspace(*str)) str++;
 
@@ -594,13 +604,18 @@ size_t trimwhitespace( char *out, size_t len, const char *str )
     }
 
     // Trim trailing space
-    end = str + strlen(str) - 1;
-    while(end > str && isspace(*end)) end--;
+    end = (char *)(str + strlen(str) - 1);
+    while(end > str && isspace(*end))
+    {
+      *end = '\0';
+      end--;
+    }
+
     end++;
 
     // Set output size to minimum of trimmed string length and buffer size minus 1
-    // out_size = (end - str) < len-1 ? (end - str) : len-1; BUG !
-    out_size = (end - str) < len-1 ? (end - str) : len;
+    //out_size = (end - str) < len-1 ? (end - str) : len - 1;
+    out_size = strlen( str );
 
     // Copy trimmed string and add null terminator
     memcpy(out, str, out_size);
@@ -1254,14 +1269,6 @@ int adat_ptt_anr2rnr( int   nADATPTTStatus,
     return nRC;
 }
 
-
-
-
-
-
-
-
-
 // ---------------------------------------------------------------------------
 // adat_send
 // ---------------------------------------------------------------------------
@@ -1506,8 +1513,6 @@ int adat_get_single_cmd_result( RIG *pRig )
                       "*** ADAT: %d acBuf ........ = 0x%08x\n",
                       gFnLevel, acBuf );
 
-            nBufLength = strlen( acBuf );
-            pcBufEnd   = acBuf + nBufLength - 1;
             pcPos      = acBuf;
 
             if(( nRC == RIG_OK ) && ( pcPos != NULL ))
@@ -1518,6 +1523,9 @@ int adat_get_single_cmd_result( RIG *pRig )
                     pcPos++;         // No, please don't ask me why this
                                      // happens ... ;-)
 
+                nBufLength = strlen( pcPos );
+                pcBufEnd   = pcPos + nBufLength - 1;
+
                 pcResult = pcPos;    // Save position
 
                 if( pcPos < pcBufEnd )
@@ -2585,6 +2593,11 @@ int adat_transaction( RIG                *pRig,
                                         memset( acBuf, 0, ADAT_RESPSZ + 1 );
 
                                         nRC = adat_receive( pRig, acBuf );
+                                        while(( nRC == RIG_OK ) &&
+                                              ( strncmp( acBuf, ADAT_BOM, strlen( ADAT_BOM )) != 0))
+                                        {
+                                          nRC = adat_receive( pRig, acBuf );
+                                        }
                                         pPriv->pcResult = strdup( acBuf );
                                     }
                                 }
@@ -2890,6 +2903,46 @@ int adat_open( RIG *pRig )
     return nRC;
 }
 
+// ---------------------------------------------------------------------------
+// Function adat_close
+// ---------------------------------------------------------------------------
+// Status: RELEASED
+
+int adat_close( RIG *pRig )
+{
+    int nRC = RIG_OK;
+
+    gFnLevel++;
+
+    rig_debug( RIG_DEBUG_TRACE,
+              "*** ADAT: %d %s (%s:%d): ENTRY. Params: pRig = 0x%08x\n",
+              gFnLevel, __func__, __FILE__, __LINE__,
+              pRig );
+
+    // Check Params
+
+    if( pRig == NULL )
+    {
+        nRC = -RIG_EARG;
+    }
+    else
+    {
+        // Now switch to interactive mode
+
+        nRC = adat_transaction( pRig, &adat_cmd_list_close_adat );
+    }
+
+    // Done !
+
+    rig_debug( RIG_DEBUG_TRACE,
+              "*** ADAT: %d %s (%s:%d): EXIT. Return Code = %d\n",
+              gFnLevel, __func__, __FILE__, __LINE__,
+              nRC );
+    gFnLevel--;
+
+    return nRC;
+}
+
 // ---------------------------------------------------------------------------
 // Function adat_get_info
 // ---------------------------------------------------------------------------
