@@ -1,25 +1,24 @@
 /*
  *  Hamlib DttSP backend - main file
- *  Copyright (c) 2001-2009 by Stephane Fillod
+ *  Copyright (c) 2001-2012 by Stephane Fillod
  *
  *  Some code derived from DttSP
  *  Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 by Frank Brickle, AB2KT and Bob McGwier, N4HY
  *
- *	$Id: dttsp.c,v 1.2 2008-05-07 22:18:25 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -49,9 +48,11 @@
  * 2 interfaces of DttSP are supported: IPC & UDP
  *
  * TODO: Transmit setup
+ *  http://openhpsdr.org/wiki/index.php?title=Ghpsdr
  */
 
 #define DEFAULT_DTTSP_CMD_PATH "/dev/shm/SDRcommands"
+#define DEFAULT_DTTSP_CMD_NET_ADDR "127.0.0.1:19001"
 #define DEFAULT_SAMPLE_RATE 48000
 
 /* DttSP constants */
@@ -76,29 +77,12 @@ struct dttsp_priv_data {
 	int rx_delta_f;
 
     hamlib_port_t meter_port;
-
-#if 0
-    union {
-        /* IPC specific */
-        struct {
-	        /* DttSP meter handle */
-	        int meter_fd;
-        };
-        /* UDP specific RIG_PORT_NETWORK_UDP */
-        struct {
-            unsigned short port;
-            struct sockaddr_in clnt;
-            int clen, flags, sock;
-            char buff[DTTSP_PORT_CLIENT_BUFSIZE];
-            int size, used;
-        };
-#endif
 };
 
-static int dttsp_ipc_init(RIG *rig);
-static int dttsp_ipc_cleanup(RIG *rig);
-static int dttsp_ipc_open(RIG *rig);
-static int dttsp_ipc_close(RIG *rig);
+static int dttsp_init(RIG *rig);
+static int dttsp_cleanup(RIG *rig);
+static int dttsp_open(RIG *rig);
+static int dttsp_close(RIG *rig);
 
 static int dttsp_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 static int dttsp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
@@ -117,11 +101,15 @@ static int dttsp_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit);
 
 
 #define TOK_TUNER_MODEL TOKEN_BACKEND(1)
+#define TOK_SAMPLE_RATE TOKEN_BACKEND(2)
 
 const struct confparams dttsp_cfg_params[] = {
 	{ TOK_TUNER_MODEL, "tuner_model", "Tuner model", "Hamlib rig tuner model number",
 		"1" /* RIG_MODEL_DUMMY */, RIG_CONF_NUMERIC, { /* .n = */ { 0, 100000, 1 } }
 	},
+	{ TOK_SAMPLE_RATE, "sample_rate", "Sample rate", "DttSP sample rate in Spls/sec",
+		"48000", RIG_CONF_NUMERIC, { /* .n = */ { 8000, 192000, 1 } }
+	},
 	/*
 	 * TODO: IF_center_freq, etc.
 	 */
@@ -173,7 +161,7 @@ const struct rig_caps dttsp_rig_caps = {
   .rig_model =      RIG_MODEL_DTTSP,
   .model_name =     "DttSP IPC",
   .mfg_name =       "DTTS Microwave Society",
-  .version =        "0.1",
+  .version =        "0.2",
   .copyright =      "GPL",
   .status =         RIG_STATUS_ALPHA,
   .rig_type =       RIG_TYPE_COMPUTER,
@@ -219,10 +207,87 @@ const struct rig_caps dttsp_rig_caps = {
 
   .priv =  NULL,
 
-  .rig_init =     dttsp_ipc_init,
-  .rig_cleanup =  dttsp_ipc_cleanup,
-  .rig_open =     dttsp_ipc_open,
-  .rig_close =    dttsp_ipc_close,
+  .rig_init =     dttsp_init,
+  .rig_cleanup =  dttsp_cleanup,
+  .rig_open =     dttsp_open,
+  .rig_close =    dttsp_close,
+
+  .cfgparams =	  dttsp_cfg_params,
+  .set_conf =     dttsp_set_conf,
+  .get_conf =     dttsp_get_conf,
+
+  .set_freq =     dttsp_set_freq,
+  .get_freq =     dttsp_get_freq,
+
+  .set_mode =     dttsp_set_mode,
+
+  .set_level =	  dttsp_set_level,
+  .get_level =	  dttsp_get_level,
+
+  .set_func =	  dttsp_set_func,
+
+  .set_rit =	  dttsp_set_rit,
+  .get_rit =	  dttsp_get_rit,
+
+  .set_ant =      dttsp_set_ant,
+};
+
+/*
+ * The same as the previous IPC, but of type RIG_PORT_UDP_NETWORK
+ */
+const struct rig_caps dttsp_udp_rig_caps = {
+  .rig_model =      RIG_MODEL_DTTSP_UDP,
+  .model_name =     "DttSP UDP",
+  .mfg_name =       "DTTS Microwave Society",
+  .version =        "0.2",
+  .copyright =      "GPL",
+  .status =         RIG_STATUS_ALPHA,
+  .rig_type =       RIG_TYPE_COMPUTER,
+  .targetable_vfo = 	 RIG_TARGETABLE_ALL,
+  .ptt_type =       RIG_PTT_RIG,
+  .dcd_type =       RIG_DCD_RIG,
+  .port_type =      RIG_PORT_UDP_NETWORK,
+  .timeout =        500,
+  .has_get_func =   DTTSP_FUNC,
+  .has_set_func =   DTTSP_FUNC,
+  .has_get_level =  DTTSP_LEVEL,
+  .has_set_level =  RIG_LEVEL_SET(DTTSP_LEVEL),
+  .has_get_parm = 	 DTTSP_PARM,
+  .has_set_parm = 	 RIG_PARM_SET(DTTSP_PARM),
+  .ctcss_list = 	 NULL,
+  .dcs_list =   	 NULL,
+  .chan_list = 	 { RIG_CHAN_END, },
+  .scan_ops = 	 DTTSP_SCAN,
+  .vfo_ops = 	 DTTSP_VFO_OP,
+  .transceive =     RIG_TRN_OFF,
+  .attenuator =     { RIG_DBLST_END, },
+  .preamp = 	 { RIG_DBLST_END, },
+  /* In fact, RX and TX ranges are dependant on the tuner */
+  .rx_range_list1 =  { {.start=kHz(150),.end=MHz(1500),.modes=DTTSP_MODES,
+		    .low_power=-1,.high_power=-1,DTTSP_VFO},
+		    RIG_FRNG_END, },
+  .tx_range_list1 =  { RIG_FRNG_END, }, /* TODO */
+  .rx_range_list2 =  { {.start=kHz(150),.end=MHz(1500),.modes=DTTSP_MODES,
+		    .low_power=-1,.high_power=-1,DTTSP_VFO},
+		    RIG_FRNG_END, },
+  .tx_range_list2 =  { RIG_FRNG_END, }, /* TODO */
+  .tuning_steps =  { {DTTSP_MODES,1}, {DTTSP_MODES,RIG_TS_ANY}, RIG_TS_END, },
+  .filters =      {
+		{RIG_MODE_SSB|RIG_MODE_CW|RIG_MODE_CWR, kHz(2.4)},
+		{RIG_MODE_AM|RIG_MODE_DSB|RIG_MODE_SAM, kHz(8)},
+		{RIG_MODE_FM, kHz(15)},
+		{DTTSP_MODES, RIG_FLT_ANY},
+		RIG_FLT_END,
+  },
+
+  .str_cal = DTTSP_REAL_STR_CAL,
+
+  .priv =  NULL,
+
+  .rig_init =     dttsp_init,
+  .rig_cleanup =  dttsp_cleanup,
+  .rig_open =     dttsp_open,
+  .rig_close =    dttsp_close,
 
   .cfgparams =	  dttsp_cfg_params,
   .set_conf =     dttsp_set_conf,
@@ -249,12 +314,7 @@ static int send_command(RIG *rig, const char *cmdstr, size_t buflen)
 {
     int ret;
 
-    if (rig->state.rigport.type.rig == RIG_PORT_NETWORK) {
-        ret = -RIG_ENIMPL;
-    } else {
-        /* IPC */
-        ret = write_block (&rig->state.rigport, cmdstr, buflen);
-    }
+    ret = write_block (&rig->state.rigport, cmdstr, buflen);
 
     return ret;
 }
@@ -265,14 +325,7 @@ static int fetch_meter (RIG *rig, int *label, float *data, int npts)
     int ret, buf_len;
     char buf[sizeof(float)*MAXMETERPTS*MAXRX];
 
-    if (priv->meter_port.type.rig == RIG_PORT_NETWORK) {
-#if 0
-        if (!select(cp->sock + 1, &fds, 0, 0, &tv))
-                         return -1;
-        if (recvfrom(cp->sock, cp->buff, cp->size, cp->flags,
-                                          (struct sockaddr *) &cp->clnt, &cp->clen) <= 0)
-                           return -2;
-#endif
+    if (priv->meter_port.type.rig == RIG_PORT_UDP_NETWORK) {
         buf_len = sizeof(int) + npts * sizeof(float);
 
         ret = read_block(&priv->meter_port, buf, buf_len);
@@ -319,6 +372,9 @@ int dttsp_set_conf(RIG *rig, token_t token, const char *val)
 	case TOK_TUNER_MODEL:
 		priv->tuner_model = atoi(val);
 		break;
+	case TOK_SAMPLE_RATE:
+		priv->sample_rate = atoi(val);
+		break;
 	default:
 		/* if it's not for the dttsp backend, maybe it's for the tuner */
 		if (priv->tuner)
@@ -346,6 +402,9 @@ int dttsp_get_conf(RIG *rig, token_t token, char *val)
 	case TOK_TUNER_MODEL:
 		sprintf(val, "%d", priv->tuner_model);
 		break;
+	case TOK_SAMPLE_RATE:
+		sprintf(val, "%d", priv->sample_rate);
+		break;
 	default:
 		/* if it's not for the dttsp backend, maybe it's for the tuner */
 		if (priv->tuner)
@@ -356,13 +415,13 @@ int dttsp_get_conf(RIG *rig, token_t token, char *val)
 	return RIG_OK;
 }
 
-int dttsp_ipc_init(RIG *rig)
+int dttsp_init(RIG *rig)
 {
   struct dttsp_priv_data *priv;
   const char *cmdpath;
   char *p;
 
-  priv = (struct dttsp_priv_data*)malloc(sizeof(struct dttsp_priv_data));
+  priv = (struct dttsp_priv_data*)calloc(1, sizeof(struct dttsp_priv_data));
   if (!priv)
 	  return -RIG_ENOMEM;
   rig->state.priv = (void*)priv;
@@ -382,15 +441,16 @@ int dttsp_ipc_init(RIG *rig)
 
   cmdpath = getenv ( "SDR_PARMPATH" );
   if (!cmdpath)
-    cmdpath = DEFAULT_DTTSP_CMD_PATH;
+    cmdpath = rig->state.rigport.type.rig == RIG_PORT_UDP_NETWORK ?
+        DEFAULT_DTTSP_CMD_NET_ADDR : DEFAULT_DTTSP_CMD_PATH;
 
-  strncpy(rig->state.rigport.pathname, cmdpath, FILPATHLEN);
+  strncpy(rig->state.rigport.pathname, cmdpath, FILPATHLEN - 1);
 
   return RIG_OK;
 }
 
 
-int dttsp_ipc_open(RIG *rig)
+int dttsp_open(RIG *rig)
 {
   struct dttsp_priv_data *priv = (struct dttsp_priv_data*)rig->state.priv;
   int ret;
@@ -403,7 +463,8 @@ int dttsp_ipc_open(RIG *rig)
   /*
    * prevent l8ps
    */
-  if (priv->tuner_model == RIG_MODEL_DTTSP) {
+  if (priv->tuner_model == RIG_MODEL_DTTSP ||
+          priv->tuner_model == RIG_MODEL_DTTSP_UDP) {
 	  return -RIG_ECONF;
   }
 
@@ -421,19 +482,32 @@ int dttsp_ipc_open(RIG *rig)
   }
 
   /* open DttSP meter pipe */
+  priv->meter_port.post_write_delay = rig->state.rigport.post_write_delay;
+  priv->meter_port.timeout = rig->state.rigport.timeout;
+  priv->meter_port.retry = rig->state.rigport.retry;
+
   p = getenv ( "SDR_METERPATH" );
   if (!p) {
     meterpath = priv->meter_port.pathname;
-  	strncpy(meterpath, rig->state.rigport.pathname, FILPATHLEN);
-  	p = strrchr(meterpath, '/');
-  	strcpy(p+1, "SDRmeter");
-	p = meterpath;
+	strncpy(meterpath, rig->state.rigport.pathname, FILPATHLEN - 1);
+    if (rig->state.rigport.type.rig == RIG_PORT_UDP_NETWORK) {
+        p = strrchr(meterpath, ':');
+        if (p)
+            strcpy(p+1, "19003");
+        else
+            strcat(meterpath, ":19003");
+        p = meterpath;
+    } else {
+        p = strrchr(meterpath, '/');
+        if (p)
+            strcpy(p+1, "SDRmeter");
+    }
   }
   if (!p) {
 	/* disabled */
 	priv->meter_port.fd = -1;
   } else {
-    priv->meter_port.type.rig = RIG_PORT_DEVICE;
+	priv->meter_port.type.rig = rig->state.rigport.type.rig;
   	ret = port_open(&priv->meter_port);
     if (ret < 0)
         return ret;
@@ -453,7 +527,7 @@ int dttsp_ipc_open(RIG *rig)
   rig->state.has_get_parm  |= priv->tuner->state.has_get_parm;
 #endif
 
-  
+
   /* Because model dummy has funky init value */
   if (priv->tuner_model == RIG_MODEL_DUMMY)
   	dttsp_set_freq(rig, RIG_VFO_CURR, priv->IF_center_freq);
@@ -464,7 +538,7 @@ int dttsp_ipc_open(RIG *rig)
 }
 
 
-int dttsp_ipc_close(RIG *rig)
+int dttsp_close(RIG *rig)
 {
   struct dttsp_priv_data *priv = (struct dttsp_priv_data*)rig->state.priv;
 
@@ -476,7 +550,7 @@ int dttsp_ipc_close(RIG *rig)
   return RIG_OK;
 }
 
-int dttsp_ipc_cleanup(RIG *rig)
+int dttsp_cleanup(RIG *rig)
 {
   struct dttsp_priv_data *priv = (struct dttsp_priv_data*)rig->state.priv;
 
@@ -512,7 +586,7 @@ int dttsp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
   max_delta = priv->sample_rate/2 - kHz(2);
 
   sprintf_freq(fstr, freq);
-  rig_debug(RIG_DEBUG_TRACE,"%s called: %s %s\n", 
+  rig_debug(RIG_DEBUG_TRACE,"%s called: %s %s\n",
  			__FUNCTION__, rig_strvfo(vfo), fstr);
 
   ret = rig_get_freq(priv->tuner, RIG_VFO_CURR, &tuner_freq);
@@ -535,10 +609,10 @@ int dttsp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 		return ret;
   }
 
-  priv->rx_delta_f = freq - tuner_freq; 
+  priv->rx_delta_f = freq - tuner_freq;
 
   sprintf_freq(fstr, tuner_freq);
-  rig_debug(RIG_DEBUG_TRACE,"%s: tuner=%s, rx_delta=%d Hz\n", 
+  rig_debug(RIG_DEBUG_TRACE,"%s: tuner=%s, rx_delta=%d Hz\n",
  			__FUNCTION__, fstr, priv->rx_delta_f);
 
   /* setRxFrequenc */
@@ -591,7 +665,7 @@ int dttsp_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
   if (width == RIG_PASSBAND_NORMAL)
 	  width = rig_passband_normal(rig, mode);
   sprintf_freq(buf, width);
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n", 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s %s\n",
   		__FUNCTION__, rig_strrmode(mode), buf);
 
   switch (mode) {
@@ -626,7 +700,7 @@ int dttsp_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
   buf_len = sprintf (buf, "setFilter %d %d\n", filter_l, filter_h );
   ret = send_command (rig, buf, buf_len);
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s: %s\n", 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s: %s\n",
   		__FUNCTION__, buf);
 
   return ret;
@@ -677,7 +751,7 @@ int dttsp_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
   char buf[32];
   float rxm[MAXRX][RXMETERPTS];
 
-  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__, 
+  rig_debug(RIG_DEBUG_VERBOSE,"%s called: %s\n",__FUNCTION__,
 				  rig_strlevel(level));
 
   switch (level) {
@@ -752,7 +826,7 @@ int dttsp_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __FUNCTION__);
 
 
-  return RIG_OK;
+  return -RIG_ENIMPL;
 }
 
 
@@ -760,7 +834,7 @@ int dttsp_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 {
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __FUNCTION__);
 
-  return RIG_OK;
+  return -RIG_ENIMPL;
 }
 
 
