@@ -111,10 +111,10 @@ const struct rig_caps ic756_caps = {
 .post_write_delay =  0,
 .timeout =  200,
 .retry =  3,
-.has_get_func =  IC756PRO_FUNC_ALL,
-.has_set_func =  IC756PRO_FUNC_ALL,
-.has_get_level =  IC756PRO_LEVEL_ALL,
-.has_set_level =  RIG_LEVEL_SET(IC756PRO_LEVEL_ALL),
+.has_get_func =  RIG_FUNC_NONE,
+.has_set_func =  RIG_FUNC_NONE,
+.has_get_level =  RIG_LEVEL_NONE,
+.has_set_level =  RIG_LEVEL_NONE,
 .has_get_parm =  RIG_PARM_NONE,
 .has_set_parm =  RIG_PARM_NONE,	/* FIXME: parms */
 .level_gran = {
@@ -208,10 +208,6 @@ const struct rig_caps ic756_caps = {
 .get_dcd =  icom_get_dcd,
 .set_ts =  icom_set_ts,
 .get_ts =  icom_get_ts,
-.set_rptr_shift =  icom_set_rptr_shift,
-.get_rptr_shift =  icom_get_rptr_shift,
-.set_rptr_offs =  icom_set_rptr_offs,
-.get_rptr_offs =  icom_get_rptr_offs,
 .set_split_freq =  icom_set_split_freq,
 .get_split_freq =  icom_get_split_freq,
 .set_split_mode =  icom_set_split_mode,
