@@ -1,20 +1,21 @@
 /*
  *  Hamlib CI-V backend - main file
- *  Copyright (c) 2000-2011 by Stephane Fillod
+ *  Copyright (c) 2000-2012 by Stephane Fillod
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
+ *
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 #ifdef HAVE_CONFIG_H
@@ -218,7 +219,7 @@ const struct ts_sc_list ic910_ts_sc_list[] = {
         { 0, 0 },
 };
 
-/* rtty filter list for some DSP rigs ie PRO */ 
+/* rtty filter list for some DSP rigs ie PRO */
 #define RTTY_FIL_NB 5
 const pbwidth_t rtty_fil[] = {
 	Hz(250),
@@ -226,7 +227,7 @@ const pbwidth_t rtty_fil[] = {
 	Hz(350),
 	Hz(500),
 	kHz(1),
-	0, 
+	0,
 };
 
 struct icom_addr {
@@ -251,9 +252,7 @@ const struct confparams icom_cfg_params[] = {
 
 /*
  * Please, if the default CI-V address of your rig is listed as UNKNOWN_ADDR,
- * send the value to <f4cfe@users.sourceforge.net> for inclusion. Thanks --SF
- *
- * TODO: sort this list with most frequent rigs first.
+ * send the value to <fillods@users.sourceforge.net> for inclusion. Thanks --SF
  */
 static const struct icom_addr icom_addr_list[] = {
 	{ RIG_MODEL_IC703, 0x68 },
@@ -304,6 +303,7 @@ static const struct icom_addr icom_addr_list[] = {
 	{ RIG_MODEL_ICR71, 0x1a },
 	{ RIG_MODEL_ICR72, 0x32 },
 	{ RIG_MODEL_ICR75, 0x5a },
+	{ RIG_MODEL_ICRX7, 0x78 },
 	{ RIG_MODEL_IC78, 0x62 },
 	{ RIG_MODEL_ICR7000, 0x08 },
 	{ RIG_MODEL_ICR7100, 0x34 },
@@ -497,15 +497,15 @@ int icom_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 }
 
 
-/* icom_get_dsp_flt 
+/* icom_get_dsp_flt
 	returns the dsp filter width in hz or 0 if the command is not implemented or error.
     This allows the default parameters to be assigned from the get_mode routine if the command is not implemented.
 	Assumes rig != null and the current mode is in mode.
-	
-	Has been tested for IC-746pro,  Should work on the all dsp rigs ie pro models. 
+
+	Has been tested for IC-746pro,  Should work on the all dsp rigs ie pro models.
 	The 746 documentation says it has the get_if_filter, but doesn't give any decoding information ? Please test.
 */
-	
+
 pbwidth_t icom_get_dsp_flt(RIG *rig, rmode_t mode) {
 
 	int retval, res_len, rfstatus;
@@ -612,11 +612,11 @@ int icom_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 	priv_caps = (const struct icom_priv_caps *) rig->caps->priv;
 
 	if (priv_caps->r2i_mode != NULL) {	/* call priv code if defined */
-	    	err = priv_caps->r2i_mode(rig, mode, width, 
+	    	err = priv_caps->r2i_mode(rig, mode, width,
 				&icmode, &icmode_ext);
-	} 
+	}
 	else {					/* else call default */
-		err = rig2icom_mode(rig, mode, width, 
+		err = rig2icom_mode(rig, mode, width,
 				&icmode, &icmode_ext);
 	}
 
@@ -661,14 +661,9 @@ int icom_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
  */
 int icom_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-	struct icom_priv_data *priv;
-	struct rig_state *rs;
 	unsigned char modebuf[MAXFRAMELEN];
 	int mode_len, retval;
 
-	rs = &rig->state;
-	priv = (struct icom_priv_data*)rs->priv;
-
 	retval = icom_transaction (rig, C_RD_MODE, -1, NULL, 0,
 				modebuf, &mode_len);
 	if (retval != RIG_OK)
@@ -696,7 +691,7 @@ int icom_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 	 * For DSP rigs these are presets, can be programmed for 30 - 41 bandwidths, depending on mode.
 	 * Lets check for dsp filters
 	 */
-	
+
 	if ((retval = icom_get_dsp_flt(rig, *mode)) !=0)
              *width = retval;
 
@@ -767,7 +762,6 @@ int icom_set_vfo(RIG *rig, vfo_t vfo)
  */
 int icom_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-	struct icom_priv_data *priv;
 	struct rig_state *rs;
 	unsigned char lvlbuf[MAXFRAMELEN], ackbuf[MAXFRAMELEN];
 	int ack_len=sizeof(ackbuf), lvl_len;
@@ -776,7 +770,6 @@ int icom_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 	int i, retval;
 
 	rs = &rig->state;
-	priv = (struct icom_priv_data*)rs->priv;
 
 
 	/*
@@ -979,7 +972,6 @@ int icom_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
  */
 int icom_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-	struct icom_priv_data *priv;
 	struct rig_state *rs;
 	unsigned char lvlbuf[MAXFRAMELEN], lvl2buf[MAXFRAMELEN];
 	int lvl_len, lvl2_len;
@@ -989,7 +981,6 @@ int icom_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 	int retval;
 
 	rs = &rig->state;
-	priv = (struct icom_priv_data*)rs->priv;
 
 	lvl2_len = 0;
 
@@ -1400,7 +1391,7 @@ int icom_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
  * icom_get_rptr_shift
  * Assumes rig!=NULL, rig->state.priv!=NULL, rptr_shift!=NULL
  * will not work for IC-746 Pro
- * NOTE: seems not to work (tested on IC-706MkIIG), please report --SF 
+ * NOTE: seems not to work (tested on IC-706MkIIG), please report --SF
  */
 int icom_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *rptr_shift)
 {
@@ -2126,7 +2117,7 @@ int icom_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 		rig_debug(RIG_DEBUG_ERR,"icom_get_func: wrong frame len=%d\n",
 					ack_len);
 		return -RIG_EPROTO;
-	} 
+	}
 	if (func != RIG_FUNC_FBKIN)
 		*status = ackbuf[2];
 	else
@@ -2317,7 +2308,7 @@ int icom_get_parm(RIG *rig, setting_t parm, value_t *val)
 
 /*
  * icom_set_ctcss_tone
- * Assumes rig!=NULL, rig->state.priv!=NULL 
+ * Assumes rig!=NULL, rig->state.priv!=NULL
  *
  * Works for 746 pro and should work for 756 xx and 7800
  */
@@ -2464,7 +2455,7 @@ int icom_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 	/* check this tone exists. That's better than nothing. */
 	for (i = 0; caps->ctcss_list[i] != 0 && i<52; i++) {
 		if (caps->ctcss_list[i] == *tone)
-			return RIG_OK;	
+			return RIG_OK;
 	}
 
 	rig_debug(RIG_DEBUG_ERR,"icom_get_ctcss_sql: CTCSS NG "
@@ -2474,7 +2465,7 @@ int icom_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 
 /*
  * icom_set_dcs_code
- * Assumes rig!=NULL, rig->state.priv!=NULL 
+ * Assumes rig!=NULL, rig->state.priv!=NULL
  */
 int icom_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 {
@@ -2589,7 +2580,7 @@ int icom_get_powerstat(RIG *rig, powerstat_t *status)
 		/* so use one of the more innculous 'set mode' commands instead */
 		cmd_len = 1;
 		cmdbuf[0] = S_PRM_TIME;
-		retval = icom_transaction(rig, C_CTL_MEM, S_MEM_MODE_SLCT, 
+		retval = icom_transaction(rig, C_CTL_MEM, S_MEM_MODE_SLCT,
 					cmdbuf, cmd_len, ackbuf, &ack_len);
 		if (retval != RIG_OK)
 			return retval;
@@ -2687,7 +2678,7 @@ int icom_set_ant(RIG * rig, vfo_t vfo, ant_t ant)
         case RIG_ANT_2: i_ant = 1; break;
         case RIG_ANT_3: i_ant = 2; break;
         case RIG_ANT_4: i_ant = 3; break;
-        default: 
+        default:
 			rig_debug(RIG_DEBUG_ERR,"Unsupported ant %#x", ant);
 			return -RIG_EINVAL;
     }
@@ -2729,7 +2720,7 @@ int icom_get_ant(RIG *rig, vfo_t vfo, ant_t *ant)
 					"len=%d\n", ackbuf[0],ack_len);
 		return -RIG_ERJCTED;
 	}
-	
+
     /* Note: with IC756/IC-756Pro/IC-7800, ackbuf[2] deals with [RX ANT] */
 
 	*ant = RIG_ANT_N(ackbuf[1]);
@@ -2819,15 +2810,11 @@ int icom_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
  */
 int icom_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
 {
-	struct icom_priv_data *priv;
-	struct rig_state *rs;
 	unsigned char scanbuf[MAXFRAMELEN];
 	unsigned char ackbuf[MAXFRAMELEN];
 	int scan_len, ack_len=sizeof(ackbuf), retval;
 	int scan_cn, scan_sc;
 
-	rs = &rig->state;
-	priv = (struct icom_priv_data*)rs->priv;
 
 	scan_len = 0;
 	scan_cn = C_CTL_SCAN;
@@ -3179,6 +3166,7 @@ DECLARE_INITRIG_BACKEND(icom)
 	rig_register(&ic9100_caps);
 	rig_register(&ic970_caps);
 
+        rig_register(&icrx7_caps);
         rig_register(&icr10_caps);
         rig_register(&icr20_caps);
         rig_register(&icr71_caps);
@@ -3194,6 +3182,7 @@ DECLARE_INITRIG_BACKEND(icom)
 	rig_register(&ic275_caps);
 	rig_register(&ic471_caps);
 	rig_register(&ic475_caps);
+	rig_register(&ic1275_caps);
 
 	rig_register(&os535_caps);
 	rig_register(&os456_caps);
