@@ -2,21 +2,20 @@
  *  Hamlib CI-V backend - description of IC-R10
  *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: icr10.c,v 1.3 2004-09-26 08:35:03 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -46,7 +45,7 @@
  */
 #define ICR10_STR_CAL UNKNOWN_IC_STR_CAL
 
-static const struct icom_priv_caps icr10_priv_caps = { 
+static const struct icom_priv_caps icr10_priv_caps = {
 		0x52,	/* default address */
 		0,		/* 731 mode */
 		r8500_ts_sc_list	/* wrong, but don't have set_ts anyway */
@@ -54,9 +53,9 @@ static const struct icom_priv_caps icr10_priv_caps = {
 
 const struct rig_caps icr10_caps = {
 .rig_model =  RIG_MODEL_ICR10,
-.model_name = "IC-R10", 
-.mfg_name =  "Icom", 
-.version =  BACKEND_VER, 
+.model_name = "IC-R10",
+.mfg_name =  "Icom",
+.version =  BACKEND_VER,
 .copyright =  "LGPL",
 .status =  RIG_STATUS_UNTESTED,
 .rig_type =  RIG_TYPE_RECEIVER|RIG_FLAG_HANDHELD,
@@ -68,13 +67,13 @@ const struct rig_caps icr10_caps = {
 .serial_data_bits =  8,
 .serial_stop_bits =  1,
 .serial_parity =  RIG_PARITY_NONE,
-.serial_handshake =  RIG_HANDSHAKE_NONE, 
+.serial_handshake =  RIG_HANDSHAKE_NONE,
 .write_delay =  0,
 .post_write_delay =  0,
 .timeout =  200,
-.retry =  3, 
+.retry =  3,
 .has_get_func =  ICR10_FUNC_ALL,
-.has_set_func =  ICR10_FUNC_ALL, 
+.has_set_func =  ICR10_FUNC_ALL,
 .has_get_level =  ICR10_LEVEL_ALL,
 .has_set_level =  RIG_LEVEL_SET(ICR10_LEVEL_ALL),
 .has_get_parm =  RIG_PARM_NONE,
