@@ -2,21 +2,20 @@
  *  Hamlib CI-V backend - description of IC-R75
  *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: icr75.c,v 1.9 2006-10-07 20:45:40 csete Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -90,12 +89,12 @@
 	.levels = RIG_LEVEL_ATT|RIG_LEVEL_PREAMP,	\
 	.channel_desc = 1,	\
 	.flags = 1,	\
-} 
+}
 
 static int icr75_set_channel(RIG *rig, const channel_t *chan);
 static int icr75_get_channel(RIG *rig, channel_t *chan);
 
-static const struct icom_priv_caps icr75_priv_caps = { 
+static const struct icom_priv_caps icr75_priv_caps = {
 		0x5a,	/* default address */
 		0,		/* 731 mode */
 		r75_ts_sc_list
@@ -103,9 +102,9 @@ static const struct icom_priv_caps icr75_priv_caps = {
 
 const struct rig_caps icr75_caps = {
 .rig_model =  RIG_MODEL_ICR75,
-.model_name = "IC-R75", 
-.mfg_name =  "Icom", 
-.version =  BACKEND_VER, 
+.model_name = "IC-R75",
+.mfg_name =  "Icom",
+.version =  BACKEND_VER,
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_RECEIVER,
@@ -117,13 +116,13 @@ const struct rig_caps icr75_caps = {
 .serial_data_bits =  8,
 .serial_stop_bits =  1,
 .serial_parity =  RIG_PARITY_NONE,
-.serial_handshake =  RIG_HANDSHAKE_NONE, 
+.serial_handshake =  RIG_HANDSHAKE_NONE,
 .write_delay =  0,
 .post_write_delay =  1,
 .timeout =  200,
-.retry =  3, 
+.retry =  3,
 .has_get_func =  ICR75_FUNC_ALL,
-.has_set_func =  ICR75_FUNC_ALL, 
+.has_set_func =  ICR75_FUNC_ALL,
 .has_get_level =  ICR75_LEVEL_ALL,
 .has_set_level =  RIG_LEVEL_SET(ICR75_LEVEL_ALL),
 .has_get_parm =  ICR75_PARM_ALL,
@@ -357,7 +356,7 @@ int icr75_get_channel(RIG *rig, channel_t *chan)
 		chan->scan_group = 0;
 		chan->flags = RIG_CHFLAG_SKIP;
 		strcpy(chan->channel_desc, "        ");
-		
+
 		/*
 		 * freqbuf should contain Cn,Data area
 		 */
@@ -366,14 +365,14 @@ int icr75_get_channel(RIG *rig, channel_t *chan)
 								chan_len);
 				return -RIG_ERJCTED;
 		}
-		
+
 		/* do this only if not a blank channel */
 		if (chan_len != 5) {
 		/*
 		 * from_bcd requires nibble len
 		 */
 			chan->flags = RIG_CHFLAG_NONE;
-			
+
 			chan->freq = from_bcd(chanbuf+5, freq_len*2);
 
 			chan_len = 4+freq_len+1;
