@@ -2,10 +2,11 @@
  *  Hamlib Elecraft backend--support extensions to Kenwood commands
  *  Copyright (C) 2010 by Nate Bargmann, n0nb@n0nb.us
  *
+ *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
  *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
+ *   version 2.1 of the License, or (at your option) any later version.
  *
  *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +15,7 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -69,5 +70,62 @@ extern const struct confparams elecraft_ext_levels[];
 /* Elecraft extension function declarations */
 int elecraft_open(RIG *rig);
 
+/* S-meter calibration tables */
+
+/* K3 defines 16 values--0-15.
+ * Table is RASTR value from SM command and dB relative to S9 == 0
+ * (see rig_get_level() in src/settings.c
+ */
+#define K3_SM_CAL { 16, \
+	{ \
+		{ 0, -54 }, \
+		{ 1, -42 }, \
+		{ 2, -36 }, \
+		{ 3, -24 }, \
+		{ 4, -12 }, \
+		{ 5, -6 }, \
+		{ 6, 0 }, \
+		{ 7, 10 }, \
+		{ 8, 15 }, \
+		{ 9, 20 }, \
+		{ 10, 30 }, \
+		{ 11, 35 }, \
+		{ 12, 40 }, \
+		{ 13, 50 }, \
+		{ 14, 55 }, \
+		{ 15, 60 }, \
+	} }
+
+
+/* K3 defines 100 values--0-100 in high resolution mode.
+ * Table is RASTR value from SMH command and dB relative to S9 == 0
+ * (see rig_get_level() in src/settings.c
+ */
+#define K3_SMH_CAL { 22, \
+	{ \
+		{ 0, -54 }, \
+		{ 5, -48 }, \
+		{ 9, -42 }, \
+		{ 14, -36 }, \
+		{ 22, -30 }, \
+		{ 24, -24 }, \
+		{ 28, -18 }, \
+		{ 33, -12 }, \
+		{ 38, -6 }, \
+		{ 42, 0 }, \
+		{ 47, 5 }, \
+		{ 53, 10 }, \
+		{ 58, 15 }, \
+		{ 63, 20 }, \
+		{ 68, 25 }, \
+		{ 73, 30 }, \
+		{ 78, 35 }, \
+		{ 83, 40 }, \
+		{ 88, 45 }, \
+		{ 93, 50 }, \
+		{ 98, 55 }, \
+		{ 103, 60 }, \
+	} }
+
 
 #endif /* _ELECRAFT_H */
