@@ -2,21 +2,20 @@
  *  Hamlib Kenwood backend - R5000 description
  *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: r5000.c,v 1.5 2009-01-28 23:30:47 azummo Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -84,7 +83,7 @@ const struct rig_caps r5000_caps = {
 .has_get_level =  R5000_LEVEL_ALL,
 .has_set_level =  RIG_LEVEL_SET(R5000_LEVEL_ALL),
 .has_get_parm =  R5000_PARM_ALL,
-.has_set_parm =  RIG_PARM_SET(R5000_PARM_ALL), 
+.has_set_parm =  RIG_PARM_SET(R5000_PARM_ALL),
 .parm_gran =  {},
 .ctcss_list =  NULL,
 .dcs_list =  NULL,
