@@ -4,22 +4,20 @@
  * This program let programs control a rotator through
  * the mean of RPC services using Hamlib.
  *
- * $Id: rpcrotd.c,v 1.4 2002-12-16 22:07:02 fillods Exp $
  *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   You should have received a copy of the GNU General Public License along
+ *   with this program; if not, write to the Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -46,7 +44,7 @@
 #include <hamlib/rotator.h>
 
 
-/* 
+/*
  * Prototypes
  */
 void usage();
@@ -205,7 +203,7 @@ main (int argc, char *argv[])
 	the_rpc_rot = rot_init(my_model);
 
 	if (!the_rpc_rot) {
-			fprintf(stderr, "Unknown rotator num %d, or initialization error.\n", 
+			fprintf(stderr, "Unknown rotator num %d, or initialization error.\n",
 							my_model);
 			fprintf(stderr, "Please check with rotctl --list option.\n");
 			exit(2);
@@ -218,7 +216,7 @@ main (int argc, char *argv[])
 	}
 
 	if (rot_file)
-		strncpy(the_rpc_rot->state.rotport.pathname, rot_file, FILPATHLEN);
+		strncpy(the_rpc_rot->state.rotport.pathname, rot_file, FILPATHLEN - 1);
 	/* FIXME: bound checking and port type == serial */
 	if (serial_rate != 0)
 		the_rpc_rot->state.rotport.parm.serial.rate = serial_rate;
