@@ -1,23 +1,22 @@
 /*
  *  Hamlib Interface - generic file based io functions
- *  Copyright (c) 2000-2009 by Stephane Fillod
+ *  Copyright (c) 2000-2012 by Stephane Fillod
  *  Copyright (c) 2000-2003 by Frank Singleton
  *
- *	$Id: iofunc.c,v 1.20 2008-11-05 23:07:38 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -53,7 +52,7 @@
 #include "parallel.h"
 #include "usb_port.h"
 #include "network.h"
-
+#include "cm108.h"
 
 /**
  * \brief Open a hamlib_port based on its rig port type
@@ -74,14 +73,14 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 			return status;
 		if (p->parm.serial.rts_state != RIG_SIGNAL_UNSET &&
 				p->parm.serial.handshake != RIG_HANDSHAKE_HARDWARE) {
-			status = ser_set_rts(p, 
+			status = ser_set_rts(p,
 					p->parm.serial.rts_state == RIG_SIGNAL_ON);
 			want_state_delay = 1;
 		}
 		if (status != 0)
 			return status;
 		if (p->parm.serial.dtr_state != RIG_SIGNAL_UNSET) {
-			status = ser_set_dtr(p, 
+			status = ser_set_dtr(p,
 					p->parm.serial.dtr_state == RIG_SIGNAL_ON);
 			want_state_delay = 1;
 		}
@@ -102,6 +101,12 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 			return status;
 		break;
 
+        case RIG_PORT_CM108:
+                status = cm108_open(p);
+                if (status < 0)
+                        return status;
+                break;
+
 	case RIG_PORT_DEVICE:
 		status = open(p->pathname, O_RDWR, 0);
 		if (status < 0)
@@ -120,6 +125,7 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 		break;	/* ez :) */
 
 	case RIG_PORT_NETWORK:
+	case RIG_PORT_UDP_NETWORK:
         /* FIXME: hardcoded network port */
 		status = network_open(p, 4532);
 		if (status < 0)
@@ -153,16 +159,20 @@ int HAMLIB_API port_close(hamlib_port_t *p, rig_port_t port_type)
 		case RIG_PORT_PARALLEL:
 			ret = par_close(p);
 			break;
+		case RIG_PORT_CM108:
+			ret = cm108_close(p);
+			break;
 		case RIG_PORT_USB:
 			ret = usb_port_close(p);
 			break;
 		case RIG_PORT_NETWORK:
+		case RIG_PORT_UDP_NETWORK:
 			ret = network_close(p);
 			break;
 
 		default:
-		    rig_debug(RIG_DEBUG_ERR, "%s: Unknown port type %d\n",
-						__func__, port_type);
+		    rig_debug(RIG_DEBUG_ERR, "%s(): Unknown port type %d\n",
+			      __func__, port_type);
             /* fall through */
 		case RIG_PORT_DEVICE:
 			ret = close(p->fd);
@@ -194,7 +204,7 @@ static ssize_t port_read(hamlib_port_t *p, void *buf, size_t count)
         }
     }
     return ret;
-  } else if (p->type.rig == RIG_PORT_NETWORK)
+  } else if (p->type.rig == RIG_PORT_NETWORK || p->type.rig == RIG_PORT_UDP_NETWORK)
 	return recv(p->fd, buf, count, 0);
   else
 	return read(p->fd, buf, count);
@@ -204,7 +214,7 @@ static ssize_t port_write(hamlib_port_t *p, const void *buf, size_t count)
 {
   if (p->type.rig == RIG_PORT_SERIAL)
 	return win32_serial_write(p->fd, buf, count);
-  else if (p->type.rig == RIG_PORT_NETWORK)
+  else if (p->type.rig == RIG_PORT_NETWORK || p->type.rig == RIG_PORT_UDP_NETWORK)
 	return send(p->fd, buf, count, 0);
   else
 	return write(p->fd, buf, count);
@@ -299,14 +309,14 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
 
 		  /* FIXME in Y2038 ... */
 		  gettimeofday(&tv, NULL);
-		  date_delay = p->post_write_delay*1000 - 
+		  date_delay = p->post_write_delay*1000 -
 				  		((tv.tv_sec - p->post_write_date.tv_sec)*1000000 +
 				  		 (tv.tv_usec - p->post_write_date.tv_usec));
 		  if (date_delay > 0) {
 				/*
-				 * optional delay after last write 
+				 * optional delay after last write
 				 */
-				usleep(date_delay); 
+				usleep(date_delay);
 		  }
 		  p->post_write_date.tv_sec = 0;
   }
@@ -316,8 +326,8 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
   	for (i=0; i < count; i++) {
 		ret = port_write(p, txbuffer+i, 1);
 		if (ret != 1) {
-			rig_debug(RIG_DEBUG_ERR,"%s():%d failed %d - %s\n", 
-				__FUNCTION__, __LINE__, ret, strerror(errno));
+			rig_debug(RIG_DEBUG_ERR,"%s():%d failed %d - %s\n",
+				__func__, __LINE__, ret, strerror(errno));
 			return -RIG_EIO;
     	}
     	usleep(p->write_delay*1000);
@@ -325,12 +335,12 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
   } else {
 	ret = port_write(p, txbuffer, count);
 	if (ret != count) {
-		rig_debug(RIG_DEBUG_ERR,"%s():%d failed %d - %s\n", 
-			__FUNCTION__, __LINE__, ret, strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s():%d failed %d - %s\n",
+			__func__, __LINE__, ret, strerror(errno));
 		return -RIG_EIO;
     	}
   }
-  
+
   if (p->post_write_delay > 0) {
 #ifdef WANT_NON_ACTIVE_POST_WRITE_DELAY
 #define POST_WRITE_DELAY_TRSHLD 10
@@ -347,9 +357,9 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
 				   /* otherwise some yaesu rigs get confused */
 				   /* with sequential fast writes*/
   }
-  rig_debug(RIG_DEBUG_TRACE,"TX %d bytes\n",count);
+  rig_debug(RIG_DEBUG_TRACE,"%s(): TX %d bytes\n", __func__, count);
   dump_hex((unsigned char *) txbuffer,count);
-  
+
   return RIG_OK;
 }
 
@@ -363,7 +373,7 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
  *
  * Read "num" bytes from "fd" and put results into
  * an array of unsigned char pointed to by "rxbuffer"
- * 
+ *
  * Blocks on read until timeout hits.
  *
  * It then reads "num" bytes into rxbuffer.
@@ -373,9 +383,9 @@ int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
  */
 
 int HAMLIB_API read_block(hamlib_port_t *p, char *rxbuffer, size_t count)
-{  
+{
   fd_set rfds, efds;
-  struct timeval tv, tv_timeout;
+  struct timeval tv, tv_timeout, start_time, end_time, elapsed_time;
   int rd_count, total_count = 0;
   int retval;
 
@@ -386,6 +396,9 @@ int HAMLIB_API read_block(hamlib_port_t *p, char *rxbuffer, size_t count)
   tv_timeout.tv_sec = p->timeout/1000;
   tv_timeout.tv_usec = (p->timeout%1000)*1000;
 
+  /* Store the time of the read loop start */
+  gettimeofday(&start_time, NULL);
+
   while (count > 0) {
 	tv = tv_timeout;	/* select may have updated it */
 
@@ -395,20 +408,27 @@ int HAMLIB_API read_block(hamlib_port_t *p, char *rxbuffer, size_t count)
 
 	retval = port_select(p, p->fd+1, &rfds, NULL, &efds, &tv);
 	if (retval == 0) {
+		/* Record timeout time and caculate elapsed time */
+		gettimeofday(&end_time, NULL);
+		timersub(&end_time, &start_time, &elapsed_time);
+
 		dump_hex((unsigned char *) rxbuffer, total_count);
-		rig_debug(RIG_DEBUG_WARN, "read_block: timedout after %d chars\n",
-						total_count);
+		rig_debug(RIG_DEBUG_WARN, "%s(): Timed out %d.%d seconds after %d chars\n",
+			  __func__, elapsed_time.tv_sec, elapsed_time.tv_usec, total_count);
+
 		return -RIG_ETIMEOUT;
 	}
 	if (retval < 0) {
 		dump_hex((unsigned char *) rxbuffer, total_count);
-		rig_debug(RIG_DEBUG_ERR,"read_block: select error after %d chars: "
-						"%s\n", total_count, strerror(errno));
+		rig_debug(RIG_DEBUG_ERR,"%s(): select() error after %d chars: %s\n",
+			  __func__, total_count, strerror(errno));
+
 		return -RIG_EIO;
 	}
 	if (FD_ISSET(p->fd, &efds)) {
-		rig_debug(RIG_DEBUG_ERR, "%s: fd error after %d chars\n", 
-                                  __FUNCTION__, total_count);
+		rig_debug(RIG_DEBUG_ERR, "%s(): fd error after %d chars\n",
+			  __func__, total_count);
+
 		return -RIG_EIO;
 	}
 
@@ -418,16 +438,18 @@ int HAMLIB_API read_block(hamlib_port_t *p, char *rxbuffer, size_t count)
 	 */
 	rd_count = port_read(p, rxbuffer+total_count, count);
 	if (rd_count < 0) {
-		rig_debug(RIG_DEBUG_ERR, "read_block: read failed - %s\n",
-							strerror(errno));
+		rig_debug(RIG_DEBUG_ERR, "%s(): read() failed - %s\n",
+			  __func__, strerror(errno));
+
 		return -RIG_EIO;
 	}
 	total_count += rd_count;
 	count -= rd_count;
   }
 
-  rig_debug(RIG_DEBUG_TRACE,"RX %d bytes\n",total_count);
+  rig_debug(RIG_DEBUG_TRACE,"%s(): RX %d bytes\n", __func__, total_count);
   dump_hex((unsigned char *) rxbuffer, total_count);
+
   return total_count;			/* return bytes count read */
 }
 
@@ -461,7 +483,7 @@ int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const
 				int stopset_len)
 {
   fd_set rfds, efds;
-  struct timeval tv, tv_timeout;
+  struct timeval tv, tv_timeout, start_time, end_time, elapsed_time;
   int rd_count, total_count = 0;
   int retval;
 
@@ -471,6 +493,9 @@ int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const
   tv_timeout.tv_sec = p->timeout/1000;
   tv_timeout.tv_usec = (p->timeout%1000)*1000;
 
+  /* Store the time of the read loop start */
+  gettimeofday(&start_time, NULL);
+
   while (total_count < rxmax-1) {
 	tv = tv_timeout;	/* select may have updated it */
 
@@ -484,13 +509,15 @@ int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const
 
 	if (retval < 0) {
 		dump_hex((unsigned char *) rxbuffer, total_count);
-		rig_debug(RIG_DEBUG_ERR, "%s: select error after %d chars: %s\n", 
-                                  __FUNCTION__, total_count, strerror(errno));
+		rig_debug(RIG_DEBUG_ERR, "%s(): select() error after %d chars: %s\n",
+			  __func__, total_count, strerror(errno));
+
 		return -RIG_EIO;
 	}
 	if (FD_ISSET(p->fd, &efds)) {
-		rig_debug(RIG_DEBUG_ERR, "%s: fd error after %d chars\n", 
-                                  __FUNCTION__, total_count);
+		rig_debug(RIG_DEBUG_ERR, "%s(): fd error after %d chars\n",
+			  __func__, total_count);
+
 		return -RIG_EIO;
 	}
 
@@ -501,8 +528,9 @@ int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const
         rd_count = port_read(p, &rxbuffer[total_count], 1);
 	if (rd_count < 0) {
 		dump_hex((unsigned char *) rxbuffer, total_count);
-		rig_debug(RIG_DEBUG_ERR, "%s: read failed - %s\n",__FUNCTION__,
-                            strerror(errno));
+		rig_debug(RIG_DEBUG_ERR, "%s(): read() failed - %s\n",
+			  __func__, strerror(errno));
+
 		return -RIG_EIO;
 	}
         ++total_count;
@@ -516,13 +544,19 @@ int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const
   rxbuffer[total_count] = '\000';
 
   if (total_count == 0) {
-    rig_debug(RIG_DEBUG_WARN, "%s: timedout without reading a character\n",
-		    __FUNCTION__);
+    /* Record timeout time and caculate elapsed time */
+    gettimeofday(&end_time, NULL);
+    timersub(&end_time, &start_time, &elapsed_time);
+
+    rig_debug(RIG_DEBUG_WARN, "%s(): Timed out %d.%d seconds without reading a character.\n",
+	      __func__, elapsed_time.tv_sec, elapsed_time.tv_usec);
+
     return -RIG_ETIMEOUT;
   }
 
-  rig_debug(RIG_DEBUG_TRACE,"RX %d characters\n",total_count);
+  rig_debug(RIG_DEBUG_TRACE,"%s(): RX %d characters\n", __func__, total_count);
   dump_hex((unsigned char *) rxbuffer, total_count);
+
   return total_count;			/* return bytes count read */
 }
 
