@@ -1,20 +1,20 @@
 /*
  *  Hamlib Interface - network communication low-level support
- *  Copyright (c) 2000-2010 by Stephane Fillod
+ *  Copyright (c) 2000-2012 by Stephane Fillod
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -102,7 +102,10 @@ int network_open(hamlib_port_t *rp, int default_port)
 
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_family = PF_UNSPEC;
-	hints.ai_socktype = SOCK_STREAM;
+	if (rp->type.rig == RIG_PORT_UDP_NETWORK)
+		hints.ai_socktype = SOCK_DGRAM;
+	else
+		hints.ai_socktype = SOCK_STREAM;
 
 	if (rp->pathname[0] == ':') {
 		portstr = rp->pathname+1;
@@ -118,7 +121,7 @@ int network_open(hamlib_port_t *rp, int default_port)
 			portstr = defaultportstr;
 		}
 	}
-    
+
 	status=getaddrinfo(hostname, portstr, &hints, &res);
 	if (status != 0) {
 		rig_debug(RIG_DEBUG_ERR, "Cannot get host \"%s\": %s\n",
