@@ -1,22 +1,22 @@
 /*
  *  Hamlib Interface - main file
- *  Copyright (c) 2000-2011 by Stephane Fillod
+ *  Copyright (c) 2000-2012 by Stephane Fillod
  *  Copyright (c) 2000-2003 by Frank Singleton
  *
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -30,7 +30,7 @@
  * \brief Ham Radio Control Libraries interface
  * \author Stephane Fillod
  * \author Frank Singleton
- * \date 2000-2011
+ * \date 2000-2012
  *
  * Hamlib provides a user-callable API, a set of "front-end" routines that
  * call rig-specific "back-end" routines which actually communicate with
@@ -66,6 +66,7 @@
 #include "usb_port.h"
 #include "network.h"
 #include "event.h"
+#include "cm108.h"
 
 /**
  * \brief Hamlib release number
@@ -82,7 +83,7 @@ const char hamlib_version[21] = "Hamlib " PACKAGE_VERSION;
  * \brief Hamlib copyright notice
  */
 const char hamlib_copyright[231] = /* hamlib 1.2 ABI specifies 231 bytes */
-  "Copyright (C) 2000-2011 Stephane Fillod\n"
+  "Copyright (C) 2000-2012 Stephane Fillod\n"
   "Copyright (C) 2000-2003 Frank Singleton\n"
   "This is free software; see the source for copying conditions.  There is NO\n"
   "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";
@@ -94,6 +95,8 @@ const char hamlib_copyright[231] = /* hamlib 1.2 ABI specifies 231 bytes */
 #define DEFAULT_SERIAL_PORT "\\\\.\\COM1"
 #elif BSD
 #define DEFAULT_SERIAL_PORT "/dev/cuaa0"
+#elif MACOSX
+#define DEFAULT_SERIAL_PORT "/dev/cu.usbserial"
 #else
 #define DEFAULT_SERIAL_PORT "/dev/ttyS0"
 #endif
@@ -106,6 +109,23 @@ const char hamlib_copyright[231] = /* hamlib 1.2 ABI specifies 231 bytes */
 #define DEFAULT_PARALLEL_PORT "/dev/parport0"
 #endif
 
+#if defined(WIN32) && !defined(__CYGWIN__)
+#define DEFAULT_CM108_PORT "fixme"
+#elif BSD
+#define DEFAULT_CM108_PORT "fixme"
+#else
+#define DEFAULT_CM108_PORT "/dev/hidraw0"
+#endif
+
+#if defined(WIN32) && !defined(__CYGWIN__)
+#define DEFAULT_CM108_PTT_BITNUM "fixme"
+#elif BSD
+#define DEFAULT_CM108_PTT_BITNUM "fixme"
+#else
+#define DEFAULT_CM108_PTT_BITNUM 2
+#endif
+
+
 #define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
 
 /*
@@ -122,7 +142,7 @@ static struct opened_rig_l *opened_rig_list = { NULL };
  * TODO: localise the messages..
  */
 static const char *rigerror_table[] = {
-	"Command completed sucessfully",
+	"Command completed successfully",
 	"Invalid parameter",
 	"Invalid configuration",
 	"Memory shortage",
@@ -290,7 +310,7 @@ RIG * HAMLIB_API rig_init(rig_model_t rig_model)
 
 	switch (caps->port_type) {
 	case RIG_PORT_SERIAL:
-	strncpy(rs->rigport.pathname, DEFAULT_SERIAL_PORT, FILPATHLEN);
+	strncpy(rs->rigport.pathname, DEFAULT_SERIAL_PORT, FILPATHLEN - 1);
 	rs->rigport.parm.serial.rate = caps->serial_rate_max;	/* fastest ! */
 	rs->rigport.parm.serial.data_bits = caps->serial_data_bits;
 	rs->rigport.parm.serial.stop_bits = caps->serial_stop_bits;
@@ -299,15 +319,24 @@ RIG * HAMLIB_API rig_init(rig_model_t rig_model)
 	break;
 
 	case RIG_PORT_PARALLEL:
-	strncpy(rs->rigport.pathname, DEFAULT_PARALLEL_PORT, FILPATHLEN);
+	strncpy(rs->rigport.pathname, DEFAULT_PARALLEL_PORT, FILPATHLEN - 1);
+	break;
+
+	/* Adding support for CM108 GPIO.  This is compatible with CM108 series
+	 * USB audio chips from CMedia and SSS1623 series USB audio chips from 3S
+	 */
+	case RIG_PORT_CM108:
+	strncpy(rs->rigport.pathname, DEFAULT_CM108_PORT, FILPATHLEN);
+	rs->rigport.parm.cm108.ptt_bitnum = DEFAULT_CM108_PTT_BITNUM;
 	break;
 
 	case RIG_PORT_NETWORK:
-	strncpy(rs->rigport.pathname, "127.0.0.1:4532", FILPATHLEN);
+	case RIG_PORT_UDP_NETWORK:
+	strncpy(rs->rigport.pathname, "127.0.0.1:4532", FILPATHLEN - 1);
 	break;
 
 	default:
-	strncpy(rs->rigport.pathname, "", FILPATHLEN);
+	strncpy(rs->rigport.pathname, "", FILPATHLEN - 1);
 	}
 
 	rs->rigport.write_delay = caps->write_delay;
@@ -497,6 +526,14 @@ int HAMLIB_API rig_open(RIG *rig)
         else
 			par_ptt_set(&rs->pttport, RIG_PTT_OFF);
 		break;
+	case RIG_PTT_CM108:
+		rs->pttport.fd = cm108_open(&rs->pttport);
+		if (rs->pttport.fd < 0)
+			rig_debug(RIG_DEBUG_ERR, "Cannot open PTT device \"%s\"\n",
+				  rs->pttport.pathname);
+		else
+			cm108_ptt_set(&rs->pttport, RIG_PTT_OFF);
+		break;
 	default:
 		rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
 						rs->pttport.type.ptt);
@@ -625,6 +662,10 @@ int HAMLIB_API rig_close(RIG *rig)
         par_ptt_set(&rs->pttport, RIG_PTT_OFF);
         port_close(&rs->pttport, RIG_PORT_PARALLEL);
 		break;
+	case RIG_PTT_CM108:
+	cm108_ptt_set(&rs->pttport, RIG_PTT_OFF);
+	port_close(&rs->pttport, RIG_PORT_CM108);
+		break;
 	default:
 		rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
 						rs->pttport.type.ptt);
@@ -1170,6 +1211,9 @@ int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 	case RIG_PTT_PARALLEL:
 		return par_ptt_set(&rig->state.pttport, ptt);
 
+	case RIG_PTT_CM108:
+		return cm108_ptt_set(&rig->state.pttport, ptt);
+
 	case RIG_PTT_NONE:
 		return -RIG_ENAVAIL;	/* not available */
 	default:
@@ -1249,6 +1293,12 @@ int HAMLIB_API rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
 		return par_ptt_get(&rig->state.pttport, ptt);
 
+	case RIG_PTT_CM108:
+		if (caps->get_ptt)
+			return caps->get_ptt(rig, vfo, ptt);
+
+		return cm108_ptt_get(&rig->state.pttport, ptt);
+
 	case RIG_PTT_NONE:
 		return -RIG_ENAVAIL;	/* not available */
 
