@@ -2,21 +2,20 @@
  *  Hamlib Interface - CTCSS and DCS tables header
  *  Copyright (c) 2000-2009 by Stephane Fillod and Frank Singleton
  *
- *	$Id: tones.h,v 1.6 2005-02-21 18:56:22 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -46,7 +45,7 @@ static const tone_t static_full_ctcss_list[] = {
  * 50 CTCSS sub-audible tones, from 67.0Hz to 254.1Hz
  *
  * \note Don't even think about changing a bit of this array, several
- * backends depend on it. If you need to, create a copy for your 
+ * backends depend on it. If you need to, create a copy for your
  * own caps. --SF
  */
 #define COMMON_CTCSS_LIST \
@@ -100,7 +99,7 @@ static const tone_t static_full_dcs_list[] = {
 };
 
 /*
- * These arrays cannot be shared on Win32 systems, 
+ * These arrays cannot be shared on Win32 systems,
  * because DLL's vars don't have constant address.
  */
 #if (defined(_WIN32) || defined(__CYGWIN__)) && !defined(IN_HAMLIB)
