@@ -3,19 +3,20 @@
  *  Copyright (c) 2000-2011 by Stephane Fillod
  *
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
  */
 
 /**
@@ -111,6 +112,18 @@ static struct usb_dev_handle *find_and_open_device(const hamlib_port_t *port)
 	rig_debug(RIG_DEBUG_VERBOSE, "%s: looking for device %04x:%04x...",
 		__func__, port->parm.usb.vid, port->parm.usb.pid);
 
+	/* Generate libusb debugging along with Hamlib debugging levels */
+	if (rig_need_debug(RIG_DEBUG_TRACE))
+		usb_set_debug(4);	/* libusb LOG_DEBUG */
+	else if (rig_need_debug(RIG_DEBUG_VERBOSE))
+		usb_set_debug(3);	/* libusb LOG_INFO */
+	else if (rig_need_debug(RIG_DEBUG_WARN))
+		usb_set_debug(2);	/* libusb LOG_WARNING */
+	else if (rig_need_debug(RIG_DEBUG_ERR) || rig_need_debug(RIG_DEBUG_BUG))
+		usb_set_debug(1);	/* libusb LOG_ERROR */
+	else
+		usb_set_debug(0);	/* libusb LOG_OFF */
+
 	for (bus = usb_get_busses(); bus != NULL; bus = bus->next) {
 		for (dev = bus->devices; dev != NULL; dev = dev->next) {
 
@@ -291,6 +304,9 @@ int usb_port_close(hamlib_port_t *port)
 {
 	struct usb_dev_handle *udh = port->handle;
 
+	/* set debugging off before closing the port */
+	usb_set_debug(0);	/* libusb LOG_OFF */
+
 	usb_release_interface (udh, port->parm.usb.iface);
 
 	/* we're assuming that closing an interface automatically releases it. */
