@@ -1,21 +1,21 @@
 /*
- * dumpcaps_rot.c - Copyright (C) 2000-2010 Stephane Fillod
+ * dumpcaps_rot.c - Copyright (C) 2000-2012 Stephane Fillod
  * This programs dumps the capabilities of a backend rig.
  *
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   You should have received a copy of the GNU General Public License along
+ *   with this program; if not, write to the Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -99,6 +99,9 @@ int dumpcaps_rot (ROT* rot, FILE *fout)
 	case RIG_PORT_NETWORK:
 			fprintf(fout, "Network link\n");
 			break;
+	case RIG_PORT_UDP_NETWORK:
+			fprintf(fout, "UDP Network link\n");
+			break;
 	case RIG_PORT_NONE:
 			fprintf(fout, "None\n");
 			break;
