@@ -5,19 +5,19 @@
  * It takes commands from network connection.
  *
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   You should have received a copy of the GNU General Public License along
+ *   with this program; if not, write to the Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -195,6 +195,8 @@ int main (int argc, char *argv[])
 					ptt_type = RIG_PTT_SERIAL_RTS;
 				else if (!strcmp(optarg, "PARALLEL"))
 					ptt_type = RIG_PTT_PARALLEL;
+				else if (!strcmp(optarg, "CM108"))
+					ptt_type = RIG_PTT_CM108;
 				else if (!strcmp(optarg, "NONE"))
 					ptt_type = RIG_PTT_NONE;
 				else
@@ -304,7 +306,7 @@ int main (int argc, char *argv[])
 	}
 
 	if (rig_file)
-		strncpy(my_rig->state.rigport.pathname, rig_file, FILPATHLEN);
+		strncpy(my_rig->state.rigport.pathname, rig_file, FILPATHLEN - 1);
 
 	/*
 	 * ex: RIG_PTT_PARALLEL and /dev/parport0
@@ -314,9 +316,9 @@ int main (int argc, char *argv[])
 	if (dcd_type != RIG_DCD_NONE)
 		my_rig->state.dcdport.type.dcd = dcd_type;
 	if (ptt_file)
-		strncpy(my_rig->state.pttport.pathname, ptt_file, FILPATHLEN);
+		strncpy(my_rig->state.pttport.pathname, ptt_file, FILPATHLEN - 1);
 	if (dcd_file)
-		strncpy(my_rig->state.dcdport.pathname, dcd_file, FILPATHLEN);
+		strncpy(my_rig->state.dcdport.pathname, dcd_file, FILPATHLEN - 1);
 	/* FIXME: bound checking and port type == serial */
 	if (serial_rate != 0)
 		my_rig->state.rigport.parm.serial.rate = serial_rate;
