@@ -3,23 +3,21 @@
  *
  * This program output S-meter vs. Azimuth curve using Hamlib.
  *
- * $Id: rigsmtr.c,v 1.2 2008-01-05 15:06:35 fillods Exp $  
  *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License along
+ *   with this program; if not, write to the Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +39,7 @@
 #include "misc.h"
 
 
-/* 
+/*
  * Prototypes
  */
 static void usage();
@@ -50,7 +48,7 @@ static int set_conf_rig(RIG *rig, char *conf_parms);
 static int set_conf_rot(ROT *rot, char *conf_parms);
 
 /*
- * Reminder: when adding long options, 
+ * Reminder: when adding long options,
  *   keep up to date SHORT_OPTIONS, usage()'s output and man page. thanks.
  * NB: do NOT use -W since it's reserved by POSIX.
  */
@@ -76,7 +74,7 @@ static struct option long_options[] =
 
 
 int main (int argc, char *argv[])
-{ 
+{
 	RIG *rig;		/* handle to rig (instance) */
 	ROT *rot;		/* handle to rotator (instance) */
 	rig_model_t rig_model = RIG_MODEL_DUMMY;
@@ -92,7 +90,7 @@ int main (int argc, char *argv[])
 	char rig_conf_parms[MAXCONFLEN] = "";
 	char rot_conf_parms[MAXCONFLEN] = "";
 
-	int with_rot = 1;
+	/* int with_rot = 1; */
 	azimuth_t azimuth;
 	elevation_t elevation;
 	unsigned step = 1000000;	/* 1e6 us */
@@ -201,7 +199,7 @@ int main (int argc, char *argv[])
   	rig = rig_init(rig_model);
 
 	if (!rig) {
-		fprintf(stderr, "Unknown rig num %d, or initialization error.\n", 
+		fprintf(stderr, "Unknown rig num %d, or initialization error.\n",
 						rig_model);
 		fprintf(stderr, "Please check with --list option.\n");
 		exit(2);
@@ -214,7 +212,7 @@ int main (int argc, char *argv[])
 	}
 
 	if (rig_file)
-		strncpy(rig->state.rigport.pathname, rig_file, FILPATHLEN);
+		strncpy(rig->state.rigport.pathname, rig_file, FILPATHLEN - 1);
 
 	/* FIXME: bound checking and port type == serial */
 	if (serial_rate != 0)
@@ -246,7 +244,7 @@ int main (int argc, char *argv[])
   	rot = rot_init(rot_model);
 
 	if (!rot) {
-		fprintf(stderr, "Unknown rot num %d, or initialization error.\n", 
+		fprintf(stderr, "Unknown rot num %d, or initialization error.\n",
 						rot_model);
 		fprintf(stderr, "Please check with --list option.\n");
 		exit(2);
@@ -259,11 +257,11 @@ int main (int argc, char *argv[])
 	}
 
 	if (rot_file)
-		strncpy(rot->state.rotport.pathname, rot_file, FILPATHLEN);
+		strncpy(rot->state.rotport.pathname, rot_file, FILPATHLEN - 1);
 
 	/* FIXME: bound checking and port type == serial */
-	if (serial_rate != 0)
-		rot->state.rotport.parm.serial.rate = serial_rate;
+	if (rot_serial_rate != 0)
+		rot->state.rotport.parm.serial.rate = rot_serial_rate;
 
 	retcode = rot_open(rot);
 	if (retcode != RIG_OK && rot_model != ROT_MODEL_DUMMY) {
@@ -271,8 +269,11 @@ int main (int argc, char *argv[])
 		exit(2);
 	}
 
-	if (rot_model == ROT_MODEL_DUMMY)
-		with_rot = 1;
+	/* Commenting out to quell "set but not used" warning.
+	 * Enable when needed for further functionality.  -N0NB
+	 */
+	/* if (rot_model == ROT_MODEL_DUMMY) */
+	/* 	with_rot = 1; */
 
 	if (verbose > 0)
 		printf("Opened rotator model %d, '%s'\n", rot->caps->rot_model,
@@ -280,7 +281,7 @@ int main (int argc, char *argv[])
 
 
 	/*******************************/
-	if (optind < argc) 
+	if (optind < argc)
 		step = atof(argv[optind])*1e6;
 
 	fprintf(stderr,"Setting rotator to azimuth %.1f°\n",rot->state.min_az);
@@ -294,7 +295,7 @@ int main (int argc, char *argv[])
 
 	fprintf(stderr,"Now initiating full 360° rotation...\n");
 	rot_set_position (rot, rot->state.max_az, 0);
-	
+
 	/* TODO: check CW or CCW */
 	/* disable AGC? */
 
