@@ -4,21 +4,20 @@
  * This shared library provides an API for communicating
  * via serial interface to an FRG-9600 using the "CAT" interface
  *
- *	$Id: frg9600.c,v 1.2 2006-10-07 15:51:38 csete Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -90,10 +89,10 @@ const struct rig_caps frg9600_caps = {
   .transceive =         RIG_TRN_OFF,
   .bank_qty =           0,
   .chan_desc_sz =       0,
-  .chan_list =          { 
+  .chan_list =          {
 				RIG_CHAN_END,
 			},
-  .rx_range_list1 =     { 
+  .rx_range_list1 =     {
     {MHz(60), MHz(905), RIG_MODE_AM|RIG_MODE_FM|RIG_MODE_WFM, -1, -1, FRG9600_VFOS },
     {MHz(60), MHz(460), RIG_MODE_SSB, -1, -1, FRG9600_VFOS },
     RIG_FRNG_END,
@@ -160,7 +159,7 @@ int frg9600_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
   unsigned char cmd[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x00};
   unsigned char md;
 
-  /* 
+  /*
    * translate mode from generic to frg9600 specific
    */
   switch(mode) {
